pub fn get_serializer(content_type: &str) -> SerializerResult<SerializerType>Expand description
Get a serializer type by content type string
Returns the appropriate serializer type for the given content type string, or an error if the content type is not supported.
Supported Content Types
application/json- JSON serializerapplication/x-msgpack- MessagePack serializer (requiresmsgpackfeature)application/x-yaml- YAML serializer (requiresyamlfeature)application/bson- BSON serializer (requiresbson-formatfeature)